#  Copyright (c) 2020 | KingKevin23 (@kingkevin023)

from webbot import Browser

class LoginError(Exception):
    pass

def get_php_session_id(email:str, password:str) -> str:
    """
    Diese Funktion loggt sich im AG-Spiel ein, liest den Cookie "PHPSESSID" aus
    und gibt diesen an den Aufrufer zurück. Für den Fall das die Logindaten
    fehlerhaft sind, wird ein LoginError erzeugt.

    :param email: E-Mail Adresse des AGS-Accounts
    :param password: Passwort des AGS-Accounts
    :raises LoginError: Anmeldedaten sind falsch
    :return: Wert des PHPSESSID Cookies
    """
    web = Browser(showWindow=False)
    web.go_to("https://www.ag-spiel.de/index.php?section=login")
    web.type(email, into="email")
    web.type(password, into="password", id="userpass")
    web.click("Einloggen")
    if "Du bist eingeloggt" in web.driver.page_source:
        for i in web.driver.get_cookies():
            if i.get("name") == "PHPSESSID":
                return i.get("value")
    elif "Es gibt keinen Benutzer mit dieser E-Mail!" in web.driver.page_source:
        raise LoginError("Keinen Benutzer mit dieser Mail!")
    elif "Das Passwort ist nicht korrekt!" in web.driver.page_source:
        raise LoginError("Falsches Passwort!")
    else:
        raise LoginError("Weder eingeloggt, noch Passwort oder Mail falsch!")


#  Copyright (c) 2020 | KingKevin23 (@kingkevin023)

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="agspiel-python-api",
    version="0.0.7",
    author="KingKevin23",
    author_email="code@kingkevin.de",
    description="Python API für das AG-Spiel",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT License",
    url="https://github.com/KingKevin23/agspiel-python-api",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
    install_requires=["webbot>=0.33"],
)